@@ -52,6 +52,31 @@ func TestEtcHostsFQDNHostname(t *testing.T) {
 			f:        etcHostsFQDNHostname,
 			expected: "host.example.com",
 		},
+		{
+			name: "etc_hosts_loopback_ipv4",
+			root: map[string]any{
+				"/etc/hosts": chezmoitest.JoinLines(
+					`invalid localhost`,
+					`127.0.0.1 localhost`,
+					`::1 localhost`,
+					`127.0.0.2 host.example.com host`,
+				),
+			},
+			f:        etcHostsFQDNHostname,
+			expected: "host.example.com",
+		},
+		{
+			name: "etc_hosts_loopback_ipv6",
+			root: map[string]any{
+				"/etc/hosts": chezmoitest.JoinLines(
+					`127.0.0.1 localhost`,
+					`::1 localhost`,
+					`::1 host.example.com host`,
+				),
+			},
+			f:        etcHostsFQDNHostname,
+			expected: "host.example.com",
+		},
 		{
 			name: "etc_hosts_whitespace_and_comments",
 			root: map[string]any{
