@@ -6,7 +6,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/google/go-github/v52/github"
+	"github.com/google/go-github/v53/github"
 
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoi"
 )
@@ -17,17 +17,17 @@ type gitHubConfig struct {
 
 type gitHubKeysState struct {
 	RequestedAt time.Time     `json:"requestedAt" yaml:"requestedAt"`
-	Keys        []*github.Key `json:"keys" yaml:"keys"`
+	Keys        []*github.Key `json:"keys"        yaml:"keys"`
 }
 
 type gitHubLatestReleaseState struct {
 	RequestedAt time.Time                 `json:"requestedAt" yaml:"requestedAt"`
-	Release     *github.RepositoryRelease `json:"release" yaml:"release"`
+	Release     *github.RepositoryRelease `json:"release"     yaml:"release"`
 }
 
 type gitHubLatestTagState struct {
 	RequestedAt time.Time             `json:"requestedAt" yaml:"requestedAt"`
-	Tag         *github.RepositoryTag `json:"tag" yaml:"tag"`
+	Tag         *github.RepositoryTag `json:"tag"         yaml:"tag"`
 }
 
 var (
@@ -53,10 +53,10 @@ func (c *Config) gitHubKeysTemplateFunc(user string) []*github.Key {
 	gitHubKeysKey := []byte(user)
 	if c.GitHub.RefreshPeriod != 0 {
 		var gitHubKeysValue gitHubKeysState
-		switch ok, err := chezmoi.PersistentStateGet(c.persistentState, gitHubKeysStateBucket, gitHubKeysKey, &gitHubKeysValue); { //nolint:lll
+		switch ok, err := chezmoi.PersistentStateGet(c.persistentState, gitHubKeysStateBucket, gitHubKeysKey, &gitHubKeysValue); {
 		case err != nil:
 			panic(err)
-		case ok && !now.After(gitHubKeysValue.RequestedAt.Add(c.GitHub.RefreshPeriod)):
+		case ok && now.Before(gitHubKeysValue.RequestedAt.Add(c.GitHub.RefreshPeriod)):
 			return gitHubKeysValue.Keys
 		}
 	}
@@ -114,10 +114,10 @@ func (c *Config) gitHubLatestReleaseTemplateFunc(ownerRepo string) *github.Repos
 	gitHubLatestReleaseKey := []byte(owner + "/" + repo)
 	if c.GitHub.RefreshPeriod != 0 {
 		var gitHubLatestReleaseStateValue gitHubLatestReleaseState
-		switch ok, err := chezmoi.PersistentStateGet(c.persistentState, gitHubLatestReleaseStateBucket, gitHubLatestReleaseKey, &gitHubLatestReleaseStateValue); { //nolint:lll
+		switch ok, err := chezmoi.PersistentStateGet(c.persistentState, gitHubLatestReleaseStateBucket, gitHubLatestReleaseKey, &gitHubLatestReleaseStateValue); {
 		case err != nil:
 			panic(err)
-		case ok && !now.After(gitHubLatestReleaseStateValue.RequestedAt.Add(c.GitHub.RefreshPeriod)):
+		case ok && now.Before(gitHubLatestReleaseStateValue.RequestedAt.Add(c.GitHub.RefreshPeriod)):
 			return gitHubLatestReleaseStateValue.Release
 		}
 	}
@@ -135,7 +135,7 @@ func (c *Config) gitHubLatestReleaseTemplateFunc(ownerRepo string) *github.Repos
 		panic(err)
 	}
 
-	if err := chezmoi.PersistentStateSet(c.persistentState, gitHubLatestReleaseStateBucket, gitHubLatestReleaseKey, &gitHubLatestReleaseState{ //nolint:lll
+	if err := chezmoi.PersistentStateSet(c.persistentState, gitHubLatestReleaseStateBucket, gitHubLatestReleaseKey, &gitHubLatestReleaseState{
 		RequestedAt: now,
 		Release:     release,
 	}); err != nil {
@@ -167,10 +167,10 @@ func (c *Config) gitHubLatestTagTemplateFunc(userRepo string) *github.Repository
 	gitHubLatestTagKey := []byte(owner + "/" + repo)
 	if c.GitHub.RefreshPeriod != 0 {
 		var gitHubLatestTagValue gitHubLatestTagState
-		switch ok, err := chezmoi.PersistentStateGet(c.persistentState, gitHubLatestTagStateBucket, gitHubLatestTagKey, &gitHubLatestTagValue); { //nolint:lll
+		switch ok, err := chezmoi.PersistentStateGet(c.persistentState, gitHubLatestTagStateBucket, gitHubLatestTagKey, &gitHubLatestTagValue); {
 		case err != nil:
 			panic(err)
-		case ok && !now.After(gitHubLatestTagValue.RequestedAt.Add(c.GitHub.RefreshPeriod)):
+		case ok && now.Before(gitHubLatestTagValue.RequestedAt.Add(c.GitHub.RefreshPeriod)):
 			return gitHubLatestTagValue.Tag
 		}
 	}
@@ -194,7 +194,7 @@ func (c *Config) gitHubLatestTagTemplateFunc(userRepo string) *github.Repository
 		tag = tags[0]
 	}
 
-	if err := chezmoi.PersistentStateSet(c.persistentState, gitHubLatestTagStateBucket, gitHubLatestTagKey, &gitHubLatestTagState{ //nolint:lll
+	if err := chezmoi.PersistentStateSet(c.persistentState, gitHubLatestTagStateBucket, gitHubLatestTagKey, &gitHubLatestTagState{
 		RequestedAt: now,
 		Tag:         tag,
 	}); err != nil {
